'''
List of major item locations.
'''

__all__ = 'MAJORLOCATIONS',

MAJORLOCATIONS = {
    'East Palace Treasure', 'Pyramid Fairy', 'Castle Dungeons',
    'Waterfall Fairy', 'Swamp Palace Treasure', 'Mushroom', 'Witch Hut',
    'Skull Woods Treasure', 'Ice Cave', 'Bombos Stone', 'Ether Rock',
    'Catfish', "Link's House", 'Dark Palace Treasure', 'Ocarina Boy',
    'Haunted Grove', 'Bug Child', 'Library', 'Bottle Vendor',
    'Tavern Back Entrance', 'Under The Bridge', 'Locksmith',
    'Misery Mire Treasure', 'Cave of Byrna', "King's Tomb", 'Lost Man',
    "Sahasrahla's Reward", 'Desert Palace Treasure', "Thieves' Town Treasure",
    'King Zora', 'Mountain Tower Treasure', 'Secret Path',
    'Master Sword Pedestal', 'Blacksmiths', 'Turtle Rock Treasure',
    'Ice Palace Treasure', "Ganon's Tower Treasure", 'Mad Batter',
    'Sanctuary', 'East Palace Boss Item', 'Desert Palace Boss Item',
    'Mountain Tower Boss Item', 'Dark Palace Boss Item',
    'Swamp Palace Boss Item', 'Skull Woods Boss Item',
    "Thieves' Town Boss Item", 'Ice Palace Boss Item',
    'Misery Mire Boss Item', 'Turtle Rock Boss Item'}
